======
Output
======

SWAN output commands


Locations
~~~~~~~~~

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.components.output.BaseLocation
    rompy_swan.components.output.FRAME
    rompy_swan.components.output.GROUP
    rompy_swan.components.output.CURVE
    rompy_swan.components.output.CURVES
    rompy_swan.components.output.RAY
    rompy_swan.components.output.ISOLINE
    rompy_swan.components.output.POINTS
    rompy_swan.components.output.POINTS_FILE
    rompy_swan.components.output.NGRID
    rompy_swan.components.output.NGRID_UNSTRUCTURED


Settings
~~~~~~~~

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.components.output.QUANTITY
    rompy_swan.components.output.QUANTITIES
    rompy_swan.components.output.OUTPUT_OPTIONS


Write
~~~~~

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.components.output.BaseWrite
    rompy_swan.components.output.BLOCK
    rompy_swan.components.output.TABLE
    rompy_swan.components.output.SPECOUT
    rompy_swan.components.output.NESTOUT
    rompy_swan.components.output.TEST
